##  Enter the Necessary Credentials in SAP LeanIX
  1. Add the Netskope integration in SAP LeanIX. For more, see [Setting Up Out-of-the-Box Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ba7437a441014af4ea67e4bf11105__setting_up_out-of-the-box_integrations).
  2. In the configuration, choose a name for the integration and the type of capabilities or data you want to get from Netskope.
  3. Enter the credentials copied from the Netskope admin portal into the corresponding fields.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754de9c7a441014924fd7216037e6e3_LowRes.png)
  4. Click Finish and wait for the connection to be established.
